@@ -48,7 +48,8 @@ class Basics:
         self.host = host
         self.port = port
         self.username = username
-        self.password = parse.quote(password)  # 针对pymongo==4.0.1的更新
+        self.password = password
+        # self.password = parse.quote(password)  # 针对pymongo==4.0.1的更新
         self.db = db
         self.collection = collection
         if self.username is None and self.password is None:
